@@ -11,7 +11,7 @@ use Hash::Merge 'merge';
 use Moo;
 use App::Sqitch::Types qw(Sqitch Target);
 
-our $VERSION = '0.9995';
+our $VERSION = '0.9996';
 
 use constant ENGINES => qw(
     pg
@@ -220,9 +220,8 @@ sub parse_args {
 
     my %engines = map { $_ => 1 } ENGINES;
     for my $arg (@{ $p{args} }) {
-        if ( !$p{no_changes} && $target && $target->plan->contains($arg) ) {
-            # A change. Keep the target if it's the default.
-            push @{ $rec{targets} } => $target unless $seen{$target->name}++;
+        if ( !$p{no_changes} && $target && -e $target->plan_file && $target->plan->contains($arg) ) {
+            # A change.
             push @{ $rec{changes} } => $arg;
         } elsif ($config->get( key => "target.$arg.uri") || URI->new($arg)->isa('URI::db')) {
             # A target. Instantiate and keep for subsequente change searches.
@@ -252,7 +251,7 @@ sub parse_args {
         }
     }
 
-    # Make sure we have the default target
+    # Make sure we have the default target if none was specified.
     push @{ $rec{targets} } => $target
         if $target && !$p{no_default} && !@{ $rec{targets} };
 
