@@ -8,10 +8,15 @@ use Locale::TextDomain qw(App-Sqitch);
 use App::Sqitch::X qw(hurl);
 use List::Util qw(first);
 use Moo;
-use App::Sqitch::Types qw(Bool);
+use App::Sqitch::Types qw(Bool Str);
 extends 'App::Sqitch::Command';
 
-our $VERSION = '0.9994';
+our $VERSION = '0.9996';
+
+has target => (
+    is      => 'ro',
+    isa     => Str,
+);
 
 has exists_only => (
     is       => 'ro',
@@ -21,6 +26,7 @@ has exists_only => (
 
 sub options {
     return qw(
+        target|t=s
         exists|e!
     );
 }
@@ -32,11 +38,15 @@ sub configure {
     return $class->SUPER::configure( $config, $opt );
 }
 
-
 sub execute {
     my ( $self, $type, $key ) = @_;
     $self->usage unless $type && $key;
-    my $plan = $self->default_target->plan;
+
+    my $target = $self->target ? App::Sqitch::Target->new(
+        sqitch => $self->sqitch,
+        name   => $self->target,
+    ) : $self->default_target;
+    my $plan = $target->plan;
 
     # Handle tags first.
     if ( $type eq 'tag' ) {
