@@ -14,7 +14,7 @@ use App::Sqitch::Types qw(Str Int Sqitch Plan Bool HashRef URI Maybe Target);
 use namespace::autoclean;
 use constant registry_release => '1.1';
 
-our $VERSION = '0.9995';
+our $VERSION = '0.9996';
 
 has sqitch => (
     is       => 'ro',
@@ -244,7 +244,7 @@ sub revert {
             $self->change_for_key($to)
         ) or do {
             # Not deployed. Is it in the plan?
-            if ( $plan->get($to) ) {
+            if ( $plan->find($to) ) {
                 # Known but not deployed.
                 hurl revert => __x(
                     'Change not deployed: "{change}"',
@@ -330,6 +330,7 @@ sub revert {
 
 sub verify {
     my ( $self, $from, $to ) = @_;
+    $self->_check_registry;
     my $sqitch   = $self->sqitch;
     my $plan     = $self->plan;
     my @changes  = $self->_load_changes( $self->deployed_changes );
@@ -393,7 +394,7 @@ sub _trim_to {
     my $sqitch = $self->sqitch;
     my $plan   = $self->plan;
 
-    # Find the change in the database.
+    # Find the to change in the database.
     my $to_id = $self->change_id_for_key( $key ) || hurl $ident => (
         $plan->contains( $key ) ? __x(
             'Change "{change}" has not been deployed',
@@ -410,7 +411,7 @@ sub _trim_to {
         change => $key,
     );
 
-    # Pope or shift changes till we find the change we want.
+    # Pop or shift changes till we find the change we want.
     if ($pop) {
         pop @{ $changes }   while $changes->[-1]->id ne $to_id;
     } else {
@@ -650,7 +651,7 @@ sub _params_for_key {
     my @off = ( offset => $offset );
     return ( @off, change => $cname, tag => $tag ) if $tag;
     return ( @off, change_id => $cname ) if $cname =~ /^[0-9a-f]{40}$/;
-    return ( @off, tag => '@' . $cname ) if $cname eq 'HEAD' || $cname eq 'ROOT';
+    return ( @off, tag => $cname ) if $cname eq 'HEAD' || $cname eq 'ROOT';
     return ( @off, change => $cname );
 }
 
@@ -753,6 +754,33 @@ sub _load_changes {
     return @changes;
 }
 
+sub _handle_lookup_index {
+    my ( $self, $change, $ids ) = @_;
+
+    # Return if 0 or 1 ID.
+    return $ids->[0] if @{ $ids } <= 1;
+
+    # Too many found! Let the user know.
+    my $sqitch = $self->sqitch;
+    $sqitch->vent(__x(
+        'Change "{change}" is ambiguous. Please specify a tag-qualified change:',
+        change => $change,
+    ));
+
+    # Lookup, emit reverse-chron list of tag-qualified changes, and die.
+    my $plan = $self->plan;
+    for my $id ( reverse @{ $ids } ) {
+        # Look in the plan, first.
+        if ( my $change = $plan->find($id) ) {
+            $self->sqitch->vent( '  * ', $change->format_tag_qualified_name )
+        } else {
+            # Look it up in the database.
+            $self->sqitch->vent( '  * ', $self->name_for_change_id($id) // '' )
+        }
+    }
+    hurl engine => __ 'Change Lookup Failed';
+}
+
 sub _deploy_by_change {
     my ( $self, $plan, $to_index ) = @_;
 
@@ -1600,7 +1628,7 @@ matches no changes.
 
 Searches the deployed changes for a change corresponding to the specified key,
 which should be in a format as described in L<sqitchchanges>, and returns the
-change's ID. Throws an exception if the key matches more than one changes.
+change's ID. Throws an exception if the key matches more than one change.
 Returns C<undef> if it matches no changes.
 
 =head3 C<change_for_key>
@@ -1806,7 +1834,8 @@ re-deployed.
 );
 
 Searches the database for the change with the specified name, tag, and offset.
-The parameters are as follows:
+Throws an exception if the key matches more than one changes. Returns C<undef>
+if it matches no changes. The parameters are as follows:
 
 =over
 
@@ -1965,10 +1994,11 @@ should be the same as for those returned by C<deployed_changes()>.
 
   my $change_name = $engine->name_for_change_id($change_id);
 
-Returns the name of the change identified by the ID argument. If a tag was
-applied to a change after that change, the name will be returned with the tag
-qualification, e.g., C<app_user@beta>. This value should be suitable for
-uniquely identifying the change, and passing to the C<get> or C<index_of>
+Returns the tag-qualified name of the change identified by the ID. If a tag
+was applied to a change after that change, the name will be returned with the
+tag qualification, e.g., C<app_user@beta>. Otherwise, it will include the
+symbolic tag C<@HEAD>. e.g., C<widgets@HEAD>. This value should be suitable
+for uniquely identifying the change, and passing to the C<get> or C<index_of>
 methods of L<App::Sqitch::Plan>.
 
 =head3 C<registered_projects>
