@@ -210,15 +210,7 @@ sub BUILDARGS {
     # Fetch params. URI can come from passed name.
     my $sqitch = $p->{sqitch} or return $p;
     my $name   = $p->{name} || '';
-    my $uri    = $p->{uri} ||= do {
-        if ($name =~ /:/) {
-            my $u = URI::db->new($name);
-            if ($u && $u->canonical_engine) {
-                $name = '';
-                $u;
-            }
-        }
-    };
+    my $uri    = $p->{uri};
 
     # If we have a URI up-front, it's all good.
     if ($uri) {
@@ -247,7 +239,8 @@ sub BUILDARGS {
             unless ($ekey) {
                 # No --engine, look for core target.
                 if ( $uri = $config->get( key => 'core.target' ) ) {
-                    # We got core.target.
+                    # We got core.target. Merge all deprecated stuff.
+                    $merge = 2;
                     $p->{name} = $name = $uri;
                     last NAME;
                 }
@@ -262,16 +255,17 @@ sub BUILDARGS {
 
             # Find the name in the engine config, or fall back on a simple URI.
             $uri = $class->_engine_var($config, $ekey, 'target') || "db:$ekey:";
+            $merge = 2; # Merge all deprecated stuff.
             $p->{name} = $name = $uri;
         }
     }
 
     # Now we should have a name. What is it?
     if ($name =~ /:/) {
-        # The name is a URI from core.target or core.engine.target.
+        # The name is a URI.
         $uri = $name;
         $name  = $p->{name} = undef;
-        $merge = 2; # Merge all deprecated stuff.
+        $merge ||= 1; # At least merge options.
     } else {
         # Well then, there had better be a config with a URI.
         $uri = $config->get( key => "target.$name.uri" ) or do {
@@ -287,7 +281,7 @@ sub BUILDARGS {
                 target => $name,
             );
         };
-        $merge = 1; # Merge only options.
+        $merge ||= 1; # At least merge options.
     }
 
     # Instantiate the URI.
@@ -363,7 +357,7 @@ sub all_targets {
     my $sqitch = $p{sqitch} or hurl 'Missing required argument: sqitch';
     my $config = $p{config} || $sqitch->config;
     my (@targets, %seen);
-    my %dump = %{ App::Sqitch::Config->load_file($config->local_file) };
+    my %dump = $config->dump;
 
     # First, load the default target.
     my $core = $dump{'core.target'} || do {
